//=============================================================================
/**
 *  @file    OrbTask.h
 *
 *  @author  Tim Bradley <bradley_t@ociweb.com>
 */
//=============================================================================

#ifndef ORB_TASK_H
#define ORB_TASK_H

#include "ace/Task.h"
#include "tao/ORB.h"

class OrbTask : public ACE_Task_Base
{
public:
  OrbTask(CORBA::ORB_ptr orb, unsigned num_threads = 1);
  virtual ~OrbTask() = default;

  virtual int open(void* x = 0);
  virtual int svc();
  virtual int close(u_long);

private:
  CORBA::ORB_var orb_;
  unsigned       num_threads_;
};

#endif
